==> nextcloud-app-calendar-1.5.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/zh_TW.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "日曆",
    "%s has published the calendar »%s«" : "%s 發佈了日曆 »%s«",
    "Hello," : "你好，",
    "We wanted to inform you that %s has published the calendar »%s«." : "通知你 %s 發佈了日曆 »%s«.",
    "Open »%s«" : "開啟 »%s«",
    "Recipient" : "接收者",
    "Too many redirects. Aborting ..." : "太多重新導向。終止中 ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "遠端伺服器未給予日曆存取權限 (HTTP {%s} error)",
    "Error connecting to remote server" : "在與遠端伺服器連線時發生了錯誤",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "請求資源發生錯誤。這有可能是因為認證不符合所致",
    "Error requesting resource on remote server" : "在與遠端伺服器要求檔案時發生了錯誤",
    "Individual" : "個人",
    "Group" : "群組",
    "Resource" : "資源",
    "Room" : "房間",
    "Unknown" : "未知",
    "Required" : "必填",
    "Optional" : "選填",
    "Does not attend" : "不參加",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "未知的時區設定({tz})，返回標準時區(UTC)",
    "Please create a calendar first." : "請先建立一個日曆。",
    "New event" : "新活動",
    "CalDAV address for clients" : "用戶端 CalDAV 位址",
    "Error saving WebCal-calendar" : "儲存WebCal-calendar發生錯誤",
    "WebDAV address for subscriptions" : "訂閱者 CalDAV 位址",
    "Email has been sent." : "Email 已經寄出",
    "There was an issue while sending your email." : "寄出email時發生問題。",
    "group" : "群組",
    "Details" : "詳細資料",
    "Attendees" : "出席者",
    "Reminders" : "提醒",
    "Repeating" : "重覆中",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "Confirmed" : "已確認",
    "Tentative" : "測試的",
    "Cancelled" : "已取消",
    "Please add a title." : "請加入標題",
    "Please select a calendar." : "請選擇一個日曆",
    "The event can not end before it starts." : "事件不能在開始前結束。",
    "Global" : "全域",
    "None" : "無",
    "Every day" : "每天",
    "Every week" : "每週",
    "Every month" : "每月",
    "Every year" : "每年",
    "never" : "永不",
    "after" : "之後",
    "How about getting started by importing some calendars?" : "是否要先載入一些日曆作為開始?",
    "At time of event" : "活動當時",
    "5 minutes before" : "5 分鐘前",
    "10 minutes before" : "10 分鐘前",
    "15 minutes before" : "15 分鐘前",
    "30 minutes before" : "30 分鐘前",
    "1 hour before" : "1 小時前",
    "2 hours before" : "2 小時前",
    "Custom" : "自訂",
    "Audio" : "音訊",
    "Pop-up" : "彈出視窗",
    "sec" : "秒",
    "min" : "分",
    "hours" : "時",
    "days" : "天",
    "week" : "週",
    "before" : "前",
    "start" : "開始",
    "end" : "結束",
    "Week {number} of {year}" : "{year} 的第 {number} 週",
    "Successfully imported" : "成功匯入",
    "Partially imported, 1 failure" : "部分匯入，1 個失敗",
    "Partially imported, {n} failures" : "部分匯入，{n} 個失敗",
    "Audio alarm" : "聲音提醒",
    "{type} {time} before the event starts" : "{type} 活動開始前 {time}",
    "{type} {time} before the event ends" : "{type} 活動結束前 {time}",
    "{type} {time} after the event starts" : "{type} 活動開始後 {time}",
    "{type} {time} after the event ends" : "{type} 活動開始前 {time}",
    "{type} at the event's start" : "{type} 活動開始時",
    "{type} at the event's end" : "{type} 活動結束時",
    "{type} at {time}" : "{type} 在 {time}",
    "{calendar} shared by {owner}" : "{calendar} 由 {owner} 分享",
    "Please enter a valid WebCal-URL" : "請輸入一個有效的WebCal-URL",
    "Title of the Event" : "活動標題",
    "Starts" : "始於",
    "Ends" : "終於",
    "All day Event" : "全天活動",
    "Delete" : "刪除",
    "Cancel" : "取消",
    "More ..." : "更多…",
    "Create" : "建立",
    "Update" : "更新",
    "Close" : " 關閉",
    "Location" : "地點",
    "Description" : "描述",
    "Event status" : "事件狀態",
    "Export" : "匯出",
    "Click here to access it" : "點擊這裡來存取",
    "Click on the link below to access it" : "點擊底下連結來存取",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "Today" : "今天",
    "Share Calendar" : "分享日曆",
    "Shared" : "已分享",
    "More" : "更多",
    "Edit" : "編輯",
    "Link" : "連結",
    "iCal link" : "iCal連結",
    "Download" : "下載",
    "Share with users or groups" : "與使用者和群組分享",
    "can edit" : "可編輯",
    "Share link" : "分享連結",
    "Public access" : "公開存取",
    "Send" : "寄出",
    "New Calendar" : "新日曆",
    "Name" : "名稱",
    "New Subscription" : "新訂閱",
    "Go back" : "返回",
    "Go forward" : "向前",
    "Calendar does not exist" : "日曆不存在",
    "Maybe you got a wrong link or the calendar was unshared?" : "連結可能錯誤或日曆未分享",
    "Edit event" : "編輯活動",
    "Delete Event" : "刪除活動",
    "Save Event" : "儲存活動",
    "Time" : "時間",
    "Type" : "類型",
    "Relative" : "相對",
    "Absolute" : "絕對",
    "Repeat" : "重覆",
    "times every" : "次每",
    "Add" : "增加",
    "Please add your email address in the personal settings in order to add attendees." : "請在個人設定頁面中設定您的 email 地址，才能新增參加者",
    "from" : "從",
    "to" : "至",
    "This event's repeating rule is not supported yet." : "還未支援此活動的重複規則",
    "Support for advanced rules will be added with subsequent updates." : "進階的規則功能將會在未來的更新加入",
    "Reset repeating rule" : "重設重複規則",
    "Repeat every ..." : "重複循環：",
    "end repeat ..." : "停止重複：",
    "times" : "次",
    "Import Calendars" : "匯入日曆",
    "Import canceled" : "已取消匯入",
    "Analyzing calendar" : "分析日曆",
    "The file contains objects incompatible with the selected calendar" : "這個檔案包含與選取的日曆不相容的物件",
    "New calendar" : "新日曆",
    "File is empty" : "檔案為空",
    "Import scheduled" : "已排程匯入",
    "Publish URL" : "發佈網址",
    "Settings & import" : "設定 & 輸入",
    "Skip simple event editor" : "略過簡易事件編輯器",
    "Show week numbers" : "顯示週數",
    "Import calendar" : "匯入日曆",
    "No Calendars selected for import" : "沒有選擇要匯入的日曆",
    "Primary CalDAV address" : "主要的 CalDAV 地址",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 地址",
    "Subscribe" : "訂閱"
},
"nplurals=1; plural=0;");

==> nextcloud-app-calendar-1.6.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/zh_TW.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "日曆",
    "%s has published the calendar »%s«" : "%s 發佈了日曆 »%s«",
    "Hello," : "嗨，",
    "We wanted to inform you that %s has published the calendar »%s«." : "通知你 %s 發佈了日曆 »%s«.",
    "Open »%s«" : "開啟 »%s«",
    "Cheers!" : "太棒了！",
    "Recipient" : "接收者",
    "Too many redirects. Aborting ..." : "太多重新導向，正在終止…",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "遠端伺服器未給予日曆存取權限 (HTTP {%s} 錯誤)",
    "Error connecting to remote server" : "在與遠端伺服器連線時發生了錯誤",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "請求資源發生錯誤。這有可能是因為認證不符合所致",
    "Error requesting resource on remote server" : "在與遠端伺服器要求檔案時發生了錯誤",
    "Individual" : "個人",
    "Group" : "群組",
    "Resource" : "資源",
    "Room" : "房間",
    "Unknown" : "未知",
    "Required" : "必填",
    "Optional" : "選填",
    "Does not attend" : "不參加",
    "{name} ({email})" : "{名字} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "未知的時區設定({tz})，返回標準時區(UTC)",
    "Please create a calendar first." : "請先建立一個日曆。",
    "New event" : "新活動",
    "CalDAV address for clients" : "用戶端 CalDAV 位址",
    "Some events in this calendar are broken. Please check the JS console for more info." : "該日曆中的有些活動格式受損，請檢查 JS 主控台",
    "Share Calendar" : "分享日曆",
    "Shared" : "已分享",
    "WebDAV address for subscriptions" : "訂閱者 CalDAV 位址",
    "group" : "群組",
    "Details" : "詳細資料",
    "Attendees" : "出席者",
    "Reminders" : "提醒",
    "Repeating" : "重覆中",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared show only busy" : "分享的時候顯示忙碌中",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "Confirmed" : "已確認",
    "Tentative" : "測試的",
    "Cancelled" : "已取消",
    "Please add a title." : "請加入標題",
    "Please select a calendar." : "請選擇一個日曆",
    "The event can not end before it starts." : "事件不能在開始前結束",
    "Global" : "全域",
    "None" : "無",
    "Every day" : "每天",
    "Every week" : "每週",
    "Every month" : "每月",
    "Every year" : "每年",
    "never" : "永不",
    "after" : "之後",
    "How about getting started by importing some calendars?" : "不如先匯入一些日曆吧？",
    "At time of event" : "活動當時",
    "5 minutes before" : "5 分鐘前",
    "10 minutes before" : "10 分鐘前",
    "15 minutes before" : "15 分鐘前",
    "30 minutes before" : "30 分鐘前",
    "1 hour before" : "1 小時前",
    "2 hours before" : "2 小時前",
    "Custom" : "自訂",
    "Audio" : "提示聲",
    "Email" : "Email",
    "Pop-up" : "彈出視窗",
    "sec" : "秒",
    "min" : "分",
    "hours" : "時",
    "days" : "天",
    "week" : "週",
    "before" : "前",
    "start" : "開始",
    "end" : "結束",
    "Editing reminders of unknown type not supported." : "不支援編輯未知類型的提醒",
    "Week {number} of {year}" : "{year} 的第 {number} 週",
    "Successfully imported {imported} objects" : "成功匯入 {imported} 個項目",
    "Imported {imported} out of {all}, skipped one duplicate" : "成功匯入 {all} 中的 {imported} 個項目，跳過一個重複的",
    "Imported {imported} out of {all}, one failure" : "成功匯入 {all} 中的 {imported} 個項目，有一項失敗",
    "Imported {imported} out of {all}, {errors} failures" : "成功匯入 {all} 中的 {imported} 個項目，有 {errors} 項失敗",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "成功匯入 {all} 中的 {imported} 個項目，跳過 {duplicates} 個重複的",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "成功匯入 {all} 中的 {imported} 個項目，跳過 {duplicates} 個重複的，有 {errors} 項失敗",
    "Audio alarm {time} before the event starts" : "在活動 {time} 前發出提示聲",
    "Pop-up {time} before the event starts" : "在活動 {time} 前跳出提示視窗",
    "Email {time} before the event starts" : "在活動 {time} 前寄出提醒 Email",
    "None {time} before the event starts" : "在活動 {time} 前無提醒",
    "{type} {time} before the event starts" : "{type} 活動開始前 {time}",
    "{type} {time} before the event ends" : "{type} 活動結束前 {time}",
    "{type} {time} after the event starts" : "{type} 活動開始後 {time}",
    "{type} {time} after the event ends" : "{type} 活動開始前 {time}",
    "{type} at the event's start" : "{type} 活動開始時",
    "{type} at the event's end" : "{type} 活動結束時",
    "{type} at {time}" : "{type} 在 {time}",
    "{calendar} shared by {owner}" : "{calendar} 由 {owner} 分享",
    "Please enter a valid WebCal-URL" : "請輸入一個有效的 WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "WebCal 代理伺服器錯誤，請聯絡系統管理員",
    "Title of the Event" : "活動標題",
    "Starts" : "開始",
    "Ends" : "結束",
    "All day Event" : "全天活動",
    "Delete" : "刪除",
    "Cancel" : "取消",
    "More ..." : "更多…",
    "Create" : "建立",
    "Update" : "更新",
    "Close" : " 關閉",
    "Location" : "地點",
    "Description" : "描述",
    "Event status" : "事件狀態",
    "Visibility when sharing" : "分享時的能見度",
    "Export" : "匯出",
    "%s has published the calendar %s" : "%s 發佈了日曆 %s",
    "Click here to access it" : "點擊這裡來存取",
    "Click on the link below to access it" : "點擊下方連結來存取",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "Today" : "今天",
    "More" : "更多",
    "Edit" : "編輯",
    "Link" : "連結",
    "iCal link" : "iCal 連結",
    "Download" : "下載",
    "Share with users or groups" : "與使用者和群組分享",
    "can edit" : "可編輯",
    "Share link" : "分享連結",
    "Public access" : "公開存取",
    "Email link to person" : "將連結 email 給別人",
    "Send" : "寄出",
    "New Calendar" : "新日曆",
    "Name" : "名稱",
    "New Subscription" : "新訂閱",
    "Go back" : "返回",
    "Go forward" : "向前",
    "Calendar does not exist" : "日曆不存在",
    "Maybe you got a wrong link or the calendar was unshared?" : "或許您拿到了錯誤的連結，或是日曆分享被關閉了？",
    "Edit event" : "編輯活動",
    "Delete Event" : "刪除活動",
    "Save Event" : "儲存活動",
    "Time" : "時間",
    "Type" : "類型",
    "Relative" : "相對",
    "Absolute" : "絕對",
    "Repeat" : "重覆",
    "times every" : "次每",
    "Add" : "加入",
    "Email address of attendee" : "參與者的 Email 地址",
    "Please add your email address in the personal settings in order to add attendees." : "請在個人設定頁面中設定您的 email 地址，才能新增參與者",
    "from" : "從",
    "to" : "至",
    "This event's repeating rule is not supported yet." : "還未支援此活動的重複規則",
    "Support for advanced rules will be added with subsequent updates." : "進階的規則功能將會在未來的更新加入",
    "Reset repeating rule" : "重設重複規則",
    "Repeat every ..." : "重複循環：",
    "end repeat ..." : "停止重複：",
    "times" : "次",
    "Import Calendars" : "匯入日曆",
    "Import canceled" : "已取消匯入",
    "Analyzing calendar" : "分析日曆",
    "The file contains objects incompatible with the selected calendar" : "這個檔案包含與選取的日曆不相容的物件",
    "New calendar" : "新日曆",
    "File is empty" : "檔案為空",
    "Import scheduled" : "已排程匯入",
    "Embed" : "嵌入",
    "Iframe to integrate" : "整合框架",
    "Publish URL" : "發佈網址",
    "Settings & import" : "設定及匯入",
    "Skip simple event editor" : "略過簡易事件編輯器",
    "Show week numbers" : "顯示週數",
    "Import calendar" : "匯入日曆",
    "No Calendars selected for import" : "沒有選擇要匯入的日曆",
    "Primary CalDAV address" : "主要的 CalDAV 地址",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 地址",
    "Subscribe" : "訂閱"
},
"nplurals=1; plural=0;");
